@@ -712,8 +712,11 @@ proc call_page {{useenv ""} {createinterp 0}} {
 		fconfigure $fd -encoding binary -translation {binary binary}
 		fconfigure $outchan -encoding binary -translation {binary binary}
 		catch {
-			fcopy $fd $outchan
+			fcopy $fd $outchan -command [list set ::rivetstarkit::fcopy([list $fd $outchan $targetfile])]
 		}
+
+		vwait ::rivetstarkit::fcopy([list $fd $outchan $targetfile])
+
 		close $fd
 	}
 }
@@ -1072,7 +1075,7 @@ if {![info exists ::env(GATEWAY_INTERFACE)]} {
 			exit 0
 		}
 		"--version" {
-			tcl_puts "RivetStarkit version 0.5.0.1376"
+			tcl_puts "RivetStarkit version 0.5.0.1377"
 			exit 0
 		}
 		default {
